@@ -46,7 +46,7 @@ class APIClient:
     ):
         """
         If raise_for_status is True, the method will raise GantryRequestException if the response
-        status code is between 400 and 500.
+        status code is >= 400
         """
         url = urljoin(self._host, path)
 
