@@ -3,7 +3,7 @@ from gantry.dataset.main import (
     delete_dataset,
     get_dataset,
     init,
-    list_dataset_commits,
+    list_dataset_versions,
     list_datasets,
 )
 
@@ -11,7 +11,7 @@ __all__ = [
     "init",
     "create_dataset",
     "get_dataset",
-    "list_dataset_commits",
+    "list_dataset_versions",
     "list_datasets",
     "delete_dataset",
 ]
