@@ -144,7 +144,7 @@ class GantryDataset:
         self._dataset_s3_prefix = dataset_s3_prefix
         self._aws_region = aws_region
 
-    def list_commits(self) -> List[Dict[str, Any]]:
+    def list_versions(self) -> List[Dict[str, Any]]:
         """
         Get dataset commits history
 
@@ -178,7 +178,7 @@ class GantryDataset:
     @typechecked
     @_ensure_dataset_exists_locally
     @_ensure_not_deleted
-    def commit(self, message: str) -> Dict[str, Any]:
+    def push_version(self, message: str) -> Dict[str, Any]:
         """
         This method will compute the difference between the current commit and the local directory,
         upload new files and modified files to dataset repo. After that we will update
@@ -261,7 +261,7 @@ class GantryDataset:
 
     @typechecked
     @_ensure_not_deleted
-    def add_file(
+    def push_file(
         self,
         file: IO,
         filename: Optional[str] = None,
@@ -292,7 +292,7 @@ class GantryDataset:
 
     @typechecked
     @_ensure_not_deleted
-    def add_tabular_file(
+    def push_tabular_file(
         self,
         file: IO,
         filename: Optional[str] = None,
@@ -326,7 +326,7 @@ class GantryDataset:
 
     @typechecked
     @_ensure_not_deleted
-    def add_dataframe(
+    def push_dataframe(
         self,
         dataframe: pd.DataFrame,
         csvname: Optional[str] = None,
@@ -917,11 +917,11 @@ class GantryDataset:
 
     def _prune_commit_info(self, commit_info):
         return {
-            "commit_id": commit_info["id"],
+            "version_id": commit_info["id"],
             "dataset": self.dataset_name,
             "message": commit_info["message"],
             # TODO:// uncomment the following line once we add sdk support for user version
-            # "user_version": commit_info["user_version"],
+            # "version_name": commit_info["user_version"],
             "created_at": commit_info["created_at"],
             "created_by": commit_info["created_by"],
             "is_latest_commit": commit_info["is_latest_commit"],
