@@ -38,7 +38,7 @@ def _dataset_client_alias(f):
 def init(
     email: str,
     backend: str = PROD_API_URL,
-    workspace: str = ".",
+    working_directory: str = ".",
     api_key: Optional[str] = None,
     bucket_name: Optional[str] = None,
     aws_region: Optional[str] = None,
@@ -57,7 +57,7 @@ def init(
     Args:
         email (str): User email
         backend (str): The backend URL. Defaults to the Gantry production URL.
-        workspace(str): dataset workspace
+        working_directory(str): dataset working directory
         api_key (str): The API key. Users can fetch the API key from the dashboard.
         bucket_name (str): Provide bucket name if you want to use your own bucket. If not provided
                         we will use a gantry managed bucket.
@@ -89,7 +89,7 @@ def init(
         bucket_name=bucket_name,
         aws_region=aws_region,
         email=email,
-        workspace=workspace,
+        working_directory=working_directory,
     )  # type: ignore[union-attr]
 
     if not _DATASET.ping():
@@ -114,8 +114,8 @@ def get_dataset(*args, **kwargs):
 
 
 @_dataset_client_alias
-def list_dataset_commits(*args, **kwargs):
-    return _DATASET.list_dataset_commits(*args, **kwargs)
+def list_dataset_versions(*args, **kwargs):
+    return _DATASET.list_dataset_versions(*args, **kwargs)
 
 
 @_dataset_client_alias
