@@ -1,3 +1,4 @@
+import copy
 import datetime
 import json
 import logging
@@ -422,6 +423,8 @@ class Gantry:
         as_batch: bool = False,
         tags: Optional[Union[Dict[str, str], List[Dict[str, str]]]] = None,
         join_keys: Optional[Union[List[str], pd.Series]] = None,
+        row_tags: Optional[List[Dict[str, str]]] = None,
+        global_tags: Optional[Dict[str, str]] = None,
     ) -> Tuple[Optional[str], List[str]]:
         """
         Function to record a batch of events containing predictions (inputs and outputs),
@@ -495,15 +498,30 @@ class Gantry:
                 environment. If this parameter is a dict, tags will apply to all records.
                 Alternatively, you can pass a list of dicts to apply tags to each record
                 independantly.
+                IMPORTANT: this parameter is in deprecation mode and it will be removed soon.
+                Use row_tags and global_tags instead.
             join_keys  (optional, Union[List[str], pd.Series[str]]): provide keys to identify
                 each record. These keys can be used later to provide feedback. If not provided,
                 a random record key will be generated for each record.
+            row_tags (optional, List[Dict[str, str]]): Specify row level tags. If provided,
+                this parameter should be a list of tags to be applied to each of the records.
+                row_tags[i] will contain the tag to attach to the i-th record. For batch global
+                tags, use the 'global_tags' parameter instead.
+            global_tags (optional, Dict[str, str]): Specify a set of tags that will be attached to
+                all ingested records from this batch. For record specific tags, you can use
+                'row_tags' param.
 
         Returns:
             A tuple of (batch_id, list[join_keys]): The batch_id will be None if records are not
                 logged as batch. The list of join_keys will be the records keys.
 
         """
+        if tags:
+            warn(
+                "Deprecated: tags parameter is going to be removed soon. "
+                "Use row_tags/global_tags instead."
+            )
+
         if inputs is not None and isinstance(inputs, pd.Series):
             inputs = inputs.to_frame()
         if outputs is not None and isinstance(outputs, pd.Series):
@@ -553,6 +571,8 @@ class Gantry:
             sizes["timestamps"] = len(timestamps)  # type: ignore
         if join_keys:
             sizes["join_keys"] = len(join_keys)  # type: ignore
+        if row_tags:
+            sizes["row_tags"] = len(row_tags)  # type: ignore
         if tags and isinstance(tags, List):
             sizes["tags"] = len(tags)  # type: ignore
 
@@ -563,9 +583,16 @@ class Gantry:
         size = list(unique_sizes)[0]
 
         if tags is None or isinstance(tags, Dict):
-            tags = [tags or {}] * size
+            tags = [copy.deepcopy(tags) if tags else {} for _ in range(size)]
             tags = cast(List[Dict[str, str]], tags)
 
+        if global_tags:
+            for t in tags:
+                t.update(global_tags)
+        if row_tags:
+            for t, row_tag in zip(tags, row_tags):
+                t.update(row_tag)
+
         for t in tags:
             _update_tags_with_env(self.environment, t)
 
