@@ -106,6 +106,9 @@ def _init(
         environment (optional, str): Set the value for the environment label attached
             to data instrumented. You can also set this parameter by setting the env
             variable GANTRY_ENVIRONMENT. If not provided, it defaults to "dev".
+            The environment is essentially a tag attached to data. To override
+            this value later, you can set an 'env' tag in the tags parameters
+            in the ingestion methods.
         send_in_background (optional, bool): set whether Gantry logging methods should
             run synchronously or not. You can also set this value by setting
             the env variable GANTRY_SEND_IN_BACKGROUND.
@@ -221,6 +224,8 @@ def log_records(
     as_batch: bool = False,
     tags: Optional[Union[Dict[str, str], List[Dict[str, str]]]] = None,
     join_keys: Optional[Union[List[str], pd.Series]] = None,
+    row_tags: Optional[List[Dict[str, str]]] = None,
+    global_tags: Optional[Dict[str, str]] = None,
 ) -> None:
     return _CLIENT.log_records(**locals())  # type: ignore[union-attr]
 
