@@ -29,7 +29,7 @@ def test_client(test_api_client):
         email=USER_EMAIL,
         bucket_name=BUCKET_NAME,
         aws_region=AWS_REGION,
-        workspace=".",
+        working_directory=".",
     )
 
 
@@ -137,7 +137,7 @@ def test_get_dataset_error(test_client, status_code, expected_error):
             test_client.get_dataset(DATASET_NAME)
 
 
-def test_dataset_commits(test_client, test_dataset, commit_history):
+def test_list_dataset_versions(test_client, test_dataset, commit_history):
     """
     Test get dataset commits
     """
@@ -160,7 +160,7 @@ def test_dataset_commits(test_client, test_dataset, commit_history):
             },
             headers={"Content-Type": "application/json"},
         )
-        commits = test_client.list_dataset_commits(DATASET_NAME)
+        commits = test_client.list_dataset_versions(DATASET_NAME)
         assert len(commits) == 2
 
 
