@@ -82,7 +82,7 @@ def test_list_commits(gantry_dataset_obj, commit_history):
             },
             headers={"Content-Type": "application/json"},
         )
-        commits = gantry_dataset_obj.list_commits()
+        commits = gantry_dataset_obj.list_versions()
         assert len(commits) == 2
 
 
@@ -172,7 +172,7 @@ def test_create_commit_without_download(gantry_dataset_obj):
     # overwrite the dataset name
     gantry_dataset_obj.dataset_name = "dataset_not_exist"
     with pytest.raises(DatasetNotFoundError):
-        gantry_dataset_obj.commit("test commit")
+        gantry_dataset_obj.push_version("test commit")
 
 
 def test_get_huggingface_dataset(gantry_dataset_obj):
@@ -389,7 +389,7 @@ def test_create_commit(datadir, gantry_dataset_obj, commit_history):
         with open(datadir / f"{DATASET_NAME}/.dataset_metadata/HEAD") as f:
             setup_resp_for_head_check(resp, json.load(f))  # we are on latest commit
 
-        gantry_dataset_obj.commit(COMMIT_MSG)
+        gantry_dataset_obj.push_version(COMMIT_MSG)
 
         diff = gantry_dataset_obj.get_diff()
 
@@ -414,7 +414,7 @@ def test_create_commit_failure(datadir, gantry_dataset_obj, commit_history):
         setup_resp_for_head_check(resp, commit_history[0])  # we are NOT on latest commit
 
         with pytest.raises(DatasetHeadOutOfDateException):
-            gantry_dataset_obj.commit(COMMIT_MSG)
+            gantry_dataset_obj.push_version(COMMIT_MSG)
 
         diff = gantry_dataset_obj.get_diff()
 
@@ -437,7 +437,7 @@ def test_create_commit_nochange(datadir, gantry_dataset_obj):
         with open(datadir / f"{dataset_name}/.dataset_metadata/HEAD") as f:
             old_commit = json.load(f)
 
-        new_commit = gantry_dataset_obj.commit("new commit")
+        new_commit = gantry_dataset_obj.push_version("new commit")
         assert old_commit == new_commit
 
 
@@ -632,14 +632,14 @@ def test_rollback_local_changes(datadir, gantry_dataset_obj):
             assert original_head == json.load(f)
 
 
-@pytest.mark.parametrize("function", ["commit", "pull", "rollback"])
+@pytest.mark.parametrize("function", ["push_version", "pull", "rollback"])
 def test_function_on_deleted_dataset(datadir, gantry_dataset_obj, function):
     with responses.RequestsMock() as resp:
         setup_resp_for_deleted_check(resp, is_deleted=True)
 
         with pytest.raises(GantryException):
-            if function == "commit":
-                gantry_dataset_obj.commit("fake commit message")
+            if function == "push_version":
+                gantry_dataset_obj.push_version("fake commit message")
             elif function == "pull":
                 gantry_dataset_obj.pull()
             elif function == "rollback":
@@ -683,7 +683,7 @@ def test_add_file(
             open(datadir / "test_file.txt", read_method),
         )
 
-        gantry_dataset_obj.add_file(
+        gantry_dataset_obj.push_file(
             open(datadir / "test_file.txt", read_method), filename, commit_message
         )
 
@@ -717,7 +717,7 @@ def test_add_tabular_file(
         )
 
         csvfile.seek(0)
-        gantry_dataset_obj.add_tabular_file(csvfile, provided_filename, commit_message)
+        gantry_dataset_obj.push_tabular_file(csvfile, provided_filename, commit_message)
 
 
 @pytest.mark.parametrize(
@@ -736,7 +736,7 @@ def test_add_tabular_file_bad_name(gantry_dataset_obj, real_filename, provided_f
         setup_resp_for_deleted_check(resp)
 
         with pytest.raises(ValueError):
-            gantry_dataset_obj.add_tabular_file(csvfile, provided_filename)
+            gantry_dataset_obj.push_tabular_file(csvfile, provided_filename)
 
 
 @pytest.mark.parametrize(
@@ -765,7 +765,7 @@ def test_add_dataframe(gantry_dataset_obj, filename, expected_filename, commit_m
             expected_file,
         )
 
-        gantry_dataset_obj.add_dataframe(df, filename, commit_message)
+        gantry_dataset_obj.push_dataframe(df, filename, commit_message)
 
 
 def update_manifest_with_checksums(datadir, dataset):
@@ -928,11 +928,11 @@ def test_load_nonexistent_stash(gantry_dataset_obj, caplog):
     assert "No stashed files were found!" in caplog.text
 
 
-@pytest.mark.parametrize(("function"), [("add_file"), ("add_tabular_file"), ("add_dataframe")])
+@pytest.mark.parametrize(("function"), [("push_file"), ("push_tabular_file"), ("push_dataframe")])
 def test_add_item_bad_parent(gantry_dataset_obj, function, commit_history):
     parent_commit_id = uuid.UUID("01234567-89ab-cdef-0123-456789abcdef")
 
-    if function == "add_dataframe":
+    if function == "push_dataframe":
         input = pd.DataFrame()
     else:
         input = StringIO()
@@ -951,19 +951,19 @@ def test_add_item_bad_parent(gantry_dataset_obj, function, commit_history):
                 headers={"Content-Type": "application/json"},
             )
 
-            if function == "add_file":
-                gantry_dataset_obj.add_file(input, parent_commit_id=parent_commit_id)
-            elif function == "add_tabular_file":
-                gantry_dataset_obj.add_tabular_file(input, parent_commit_id=parent_commit_id)
-            elif function == "add_dataframe":
-                gantry_dataset_obj.add_dataframe(input, parent_commit_id=parent_commit_id)
+            if function == "push_file":
+                gantry_dataset_obj.push_file(input, parent_commit_id=parent_commit_id)
+            elif function == "push_tabular_file":
+                gantry_dataset_obj.push_tabular_file(input, parent_commit_id=parent_commit_id)
+            elif function == "push_dataframe":
+                gantry_dataset_obj.push_dataframe(input, parent_commit_id=parent_commit_id)
 
 
-@pytest.mark.parametrize(("function"), [("add_file"), ("add_tabular_file"), ("add_dataframe")])
+@pytest.mark.parametrize(("function"), [("push_file"), ("push_tabular_file"), ("push_dataframe")])
 def test_add_item_good_parent(gantry_dataset_obj, function, commit_history, add_file_commit):
     parent_commit_id = commit_history[0]["id"]
 
-    if function == "add_dataframe":
+    if function == "push_dataframe":
         input = pd.DataFrame()
     else:
         input = StringIO()
@@ -990,15 +990,15 @@ def test_add_item_good_parent(gantry_dataset_obj, function, commit_history, add_
             headers={"Content-Type": "application/json"},
         )
 
-        if function == "add_file":
-            new_commit = gantry_dataset_obj.add_file(input, parent_commit_id=parent_commit_id)
-        elif function == "add_tabular_file":
-            new_commit = gantry_dataset_obj.add_tabular_file(
+        if function == "push_file":
+            new_commit = gantry_dataset_obj.push_file(input, parent_commit_id=parent_commit_id)
+        elif function == "push_tabular_file":
+            new_commit = gantry_dataset_obj.push_tabular_file(
                 input, parent_commit_id=parent_commit_id
             )
-        elif function == "add_dataframe":
-            new_commit = gantry_dataset_obj.add_dataframe(input, parent_commit_id=parent_commit_id)
+        elif function == "push_dataframe":
+            new_commit = gantry_dataset_obj.push_dataframe(input, parent_commit_id=parent_commit_id)
 
-        new_commit["commit_id"] == add_file_commit["id"]
+        new_commit["version_id"] == add_file_commit["id"]
         new_commit["dataset"] == gantry_dataset_obj.dataset_name
         new_commit["message"] == "add file test commit"
